@@ -1,12 +1,14 @@
+# flake8: noqa
+# @TODO: code formatting issue for 20.07 release
 from typing import List
 from functools import partial
 
 import torch
 
-from ..abn import ABN
-from ..blocks.core import _get_block
-from ..blocks.psp import PSPBlock
-from .core import DecoderSpec
+from catalyst.contrib.models.cv.segmentation.abn import ABN
+from catalyst.contrib.models.cv.segmentation.blocks.core import _get_block  # noqa: WPS450, E501
+from catalyst.contrib.models.cv.segmentation.blocks.psp import PSPBlock
+from catalyst.contrib.models.cv.segmentation.decoder.core import DecoderSpec
 
 
 class PSPDecoder(DecoderSpec):
@@ -26,9 +28,7 @@ class PSPDecoder(DecoderSpec):
         psp_out_channels: int = self._get(in_channels)
 
         self.psp = PSPBlock(
-            psp_out_channels,
-            pool_sizes=(1, 2, 3, 6),
-            use_batchnorm=use_batchnorm,
+            psp_out_channels, pool_sizes=(1, 2, 3, 6), use_batchnorm=use_batchnorm,
         )
 
         self.conv = _get_block(
@@ -65,3 +65,6 @@ class PSPDecoder(DecoderSpec):
         x = self.psp(features)
         x = self.conv(x)
         return [x]
+
+
+__all__ = ["PSPDecoder"]
