@@ -7,30 +7,17 @@ from torch import nn
 import torchvision
 
 from catalyst import utils
+from catalyst.contrib.models.cv.segmentation.encoder.core import (  # noqa: WPS450, E501
+    _take,
+    EncoderSpec,
+)
 
-from .core import _take, EncoderSpec
-
-RESNET_PARAMS = {
-    "resnet18": {
-        "channels": [64, 64, 128, 256, 512],
-        "strides": [2, 4, 8, 16, 32],
-    },
-    "resnet34": {
-        "channels": [64, 64, 128, 256, 512],
-        "strides": [2, 4, 8, 16, 32],
-    },
-    "resnet50": {
-        "channels": [64, 256, 512, 1024, 2048],
-        "strides": [2, 4, 8, 16, 32],
-    },
-    "resnet101": {
-        "channels": [64, 256, 512, 1024, 2048],
-        "strides": [2, 4, 8, 16, 32],
-    },
-    "resnet152": {
-        "channels": [64, 256, 512, 1024, 2048],
-        "strides": [2, 4, 8, 16, 32],
-    },
+RESNET_PARAMS = {  # noqa: WPS407
+    "resnet18": {"channels": [64, 64, 128, 256, 512], "strides": [2, 4, 8, 16, 32]},
+    "resnet34": {"channels": [64, 64, 128, 256, 512], "strides": [2, 4, 8, 16, 32]},
+    "resnet50": {"channels": [64, 256, 512, 1024, 2048], "strides": [2, 4, 8, 16, 32]},
+    "resnet101": {"channels": [64, 256, 512, 1024, 2048], "strides": [2, 4, 8, 16, 32]},
+    "resnet152": {"channels": [64, 256, 512, 1024, 2048], "strides": [2, 4, 8, 16, 32]},
 }
 
 
@@ -55,12 +42,12 @@ class ResnetEncoder(EncoderSpec):
     ):
         """
         Args:
-            arch (str): Name for resnet. Have to be one of
+            arch: Name for resnet. Have to be one of
                 resnet18, resnet34, resnet50, resnet101, resnet152
-            pretrained (bool): If True, returns a model pre-trained on ImageNet
-            requires_grad (bool): Flag for set_requires_grad.
+            pretrained: If True, returns a model pre-trained on ImageNet
+            requires_grad: Flag for set_requires_grad.
                 If None, calculates as ``not requires_grad``
-            layers_indices (List[int]): layers of encoders
+            layers_indices: layers of encoders
                 used for segmentation
                 If None, calculates as ``[1, 2, 3, 4]``
             state_dict (Union[dict, str, Path]): Path to ``torch.Model``
@@ -83,22 +70,10 @@ class ResnetEncoder(EncoderSpec):
         self._strides = _take(self._strides, self._layers_indices)
 
         layer0 = nn.Sequential(
-            OrderedDict(
-                [
-                    ("conv1", resnet.conv1),
-                    ("bn1", resnet.bn1),
-                    ("relu", resnet.relu),
-                ]
-            )
+            OrderedDict([("conv1", resnet.conv1), ("bn1", resnet.bn1), ("relu", resnet.relu)])
         )
         self._layers = nn.ModuleList(
-            [
-                layer0,
-                resnet.layer1,
-                resnet.layer2,
-                resnet.layer3,
-                resnet.layer4,
-            ]
+            [layer0, resnet.layer1, resnet.layer2, resnet.layer3, resnet.layer4]
         )
         self.maxpool0 = resnet.maxpool
 
@@ -114,7 +89,7 @@ class ResnetEncoder(EncoderSpec):
 
     @property
     def out_strides(self) -> List[int]:
-        """@TODO: Docs. Contribution is welcome."""
+        """Number of strides produced by the block."""
         return self._strides
 
     def forward(self, x: torch.Tensor) -> List[torch.Tensor]:
@@ -132,3 +107,6 @@ class ResnetEncoder(EncoderSpec):
 
         output = _take(output, self._layers_indices)
         return output
+
+
+__all__ = ["ResnetEncoder"]
