@@ -1,8 +1,13 @@
+# flake8: noqa
+# @TODO: code formatting issue for 20.07 release
 from typing import List, Union
 
 from torch import nn
 
-from .sequential import _process_additional_params, SequentialNet
+from catalyst.contrib.models.sequential import (  # noqa: WPS450
+    _process_additional_params,
+    SequentialNet,
+)
 
 
 def get_convolution_net(
@@ -35,9 +40,7 @@ def get_convolution_net(
             "stride": stride,
             "groups": group,
         }
-        for bias, kernel_size, stride, group in zip(
-            use_bias, kernel_sizes, strides, groups
-        )
+        for bias, kernel_size, stride, group in zip(use_bias, kernel_sizes, strides, groups)
     ]
 
     if dropout_rate is not None:
@@ -45,8 +48,7 @@ def get_convolution_net(
             {"module": nn.Dropout2d, "p": dropout_rate}
             if isinstance(dropout_rate, float)
             else [
-                {"module": nn.Dropout2d, "p": p} if p is not None else None
-                for p in dropout_rate
+                {"module": nn.Dropout2d, "p": p} if p is not None else None for p in dropout_rate
             ]
         )
     else:
@@ -88,10 +90,7 @@ def get_linear_net(
         dropout_fn = (
             {"module": nn.Dropout, "p": dropout_rate}
             if isinstance(dropout_rate, float)
-            else [
-                {"module": nn.Dropout, "p": p} if p is not None else None
-                for p in dropout_rate
-            ]
+            else [{"module": nn.Dropout, "p": p} if p is not None else None for p in dropout_rate]
         )
     else:
         dropout_fn = None
@@ -108,3 +107,6 @@ def get_linear_net(
     )
 
     return net
+
+
+__all__ = ["get_convolution_net", "get_linear_net"]
