@@ -1,3 +1,5 @@
+# flake8: noqa
+# @TODO: code formatting issue for 20.07 release
 import torch
 from torch import nn
 
@@ -8,15 +10,13 @@ class RMSNorm(nn.Module):
     @TODO: Docs (link to paper). Contribution is welcome.
     """
 
-    def __init__(
-        self, dimension: int, epsilon: float = 1e-8, is_bias: bool = False
-    ):
+    def __init__(self, dimension: int, epsilon: float = 1e-8, is_bias: bool = False):
         """
         Args:
-            dimension (int): the dimension of the layer output to normalize
-            epsilon (float): an epsilon to prevent dividing by zero
+            dimension: the dimension of the layer output to normalize
+            epsilon: an epsilon to prevent dividing by zero
                 in case the layer has zero variance. (default = 1e-8)
-            is_bias (bool): a boolean value whether to include bias term
+            is_bias: a boolean value whether to include bias term
                 while normalization
         """
         super().__init__()
@@ -34,3 +34,6 @@ class RMSNorm(nn.Module):
         if self.is_bias:
             return self.scale * x_norm + self.bias
         return self.scale * x_norm
+
+
+__all__ = ["RMSNorm"]
