@@ -19,9 +19,9 @@ class QHAdamW(Optimizer):
         >>> loss_fn(model(input), target).backward()
         >>> optimizer.step()
 
-    Main origins of inspiration:
-        https://github.com/iprally/qhadamw-pytorch/blob/master/qhadamw.py
-        (MIT License)
+    Adapted from:
+    https://github.com/iprally/qhadamw-pytorch/blob/master/qhadamw.py
+    (MIT License)
 
     .. _Decoupled Weight Decay Regularization:
         https://arxiv.org/abs/1711.05101
@@ -30,13 +30,7 @@ class QHAdamW(Optimizer):
     """
 
     def __init__(
-        self,
-        params,
-        lr=1e-3,
-        betas=(0.995, 0.999),
-        nus=(0.7, 1.0),
-        weight_decay=0.0,
-        eps=1e-8,
+        self, params, lr=1e-3, betas=(0.995, 0.999), nus=(0.7, 1.0), weight_decay=0.0, eps=1e-8,
     ):
         r"""
         Args:
@@ -84,6 +78,12 @@ class QHAdamW(Optimizer):
         Args:
             closure (callable, optional): A closure that reevaluates
                 the model and returns the loss.
+
+        Returns:
+            computed loss
+
+        Raises:
+            RuntimeError: QHAdamW does not support sparse gradients
         """
         loss = None
         if closure is not None:
@@ -102,9 +102,7 @@ class QHAdamW(Optimizer):
 
                 d_p = p.grad.data
                 if d_p.is_sparse:
-                    raise RuntimeError(
-                        "QHAdamW does not support sparse gradients"
-                    )
+                    raise RuntimeError("QHAdamW does not support sparse gradients")
 
                 param_state = self.state[p]
 
@@ -120,12 +118,8 @@ class QHAdamW(Optimizer):
                     param_state["exp_avg"] = torch.zeros_like(p.data)
                     param_state["exp_avg_sq"] = torch.zeros_like(p.data)
 
-                param_state["beta1_weight"] = (
-                    1.0 + beta1 * param_state["beta1_weight"]
-                )
-                param_state["beta2_weight"] = (
-                    1.0 + beta2 * param_state["beta2_weight"]
-                )
+                param_state["beta1_weight"] = 1.0 + beta1 * param_state["beta1_weight"]
+                param_state["beta2_weight"] = 1.0 + beta2 * param_state["beta2_weight"]
 
                 beta1_weight = param_state["beta1_weight"]
                 beta2_weight = param_state["beta2_weight"]
@@ -152,8 +146,9 @@ class QHAdamW(Optimizer):
                 # p.data.addcdiv_(-lr, avg_grad, avg_grad_rms)
 
                 # Implementation following AdamW paper:
-                p.data.add_(-weight_decay, p.data).addcdiv_(
-                    -lr, avg_grad, avg_grad_rms
-                )
+                p.data.add_(-weight_decay, p.data).addcdiv_(-lr, avg_grad, avg_grad_rms)
 
         return loss
+
+
+__all__ = ["QHAdamW"]
