@@ -13,16 +13,14 @@ class RAdam(Optimizer):
 
     @TODO: Docs (add `Example`). Contribution is welcome
 
-    Main origins of inspiration:
-        https://github.com/LiyuanLucasLiu/RAdam (Apache-2.0 License)
+    Adapted from:
+    https://github.com/LiyuanLucasLiu/RAdam (Apache-2.0 License)
 
     .. _On the Variance of the Adaptive Learning Rate and Beyond:
         https://arxiv.org/abs/1908.03265
     """
 
-    def __init__(
-        self, params, lr=1e-3, betas=(0.9, 0.999), eps=1e-8, weight_decay=0
-    ):
+    def __init__(self, params, lr=1e-3, betas=(0.9, 0.999), eps=1e-8, weight_decay=0):
         """@TODO: Docs. Contribution is welcome."""
         defaults = {
             "lr": lr,
@@ -43,6 +41,12 @@ class RAdam(Optimizer):
         Args:
             closure (callable, optional): A closure that reevaluates
                 the model and returns the loss.
+
+        Returns:
+            computed loss
+
+        Raises:
+            RuntimeError: RAdam does not support sparse gradients
         """
         loss = None
         if closure is not None:
@@ -55,9 +59,7 @@ class RAdam(Optimizer):
                     continue
                 grad = p.grad.data.float()
                 if grad.is_sparse:
-                    raise RuntimeError(
-                        "RAdam does not support sparse gradients"
-                    )
+                    raise RuntimeError("RAdam does not support sparse gradients")
 
                 p_data_fp32 = p.data.float()
 
@@ -69,9 +71,7 @@ class RAdam(Optimizer):
                     state["exp_avg_sq"] = torch.zeros_like(p_data_fp32)
                 else:
                     state["exp_avg"] = state["exp_avg"].type_as(p_data_fp32)
-                    state["exp_avg_sq"] = state["exp_avg_sq"].type_as(
-                        p_data_fp32
-                    )
+                    state["exp_avg_sq"] = state["exp_avg_sq"].type_as(p_data_fp32)
 
                 exp_avg, exp_avg_sq = state["exp_avg"], state["exp_avg_sq"]
                 beta1, beta2 = group["betas"]
@@ -82,28 +82,26 @@ class RAdam(Optimizer):
                 state["step"] += 1
                 buffered = self.buffer[int(state["step"] % 10)]
                 if state["step"] == buffered[0]:
-                    N_sma, step_size = buffered[1], buffered[2]
+                    n_sma, step_size = buffered[1], buffered[2]
                 else:
                     buffered[0] = state["step"]
                     beta2_t = beta2 ** state["step"]
-                    N_sma_max = 2 / (1 - beta2) - 1
-                    N_sma = N_sma_max - 2 * state["step"] * beta2_t / (
-                        1 - beta2_t
-                    )
-                    buffered[1] = N_sma
+                    n_sma_max = 2 / (1 - beta2) - 1
+                    n_sma = n_sma_max - 2 * state["step"] * beta2_t / (1 - beta2_t)
+                    buffered[1] = n_sma
 
                     # more conservative since it's an approximated value
-                    if N_sma >= 5:
+                    if n_sma >= 5:
                         step_size = (
                             group["lr"]
                             * math.sqrt(
                                 (1 - beta2_t)
-                                * (N_sma - 4)
-                                / (N_sma_max - 4)
-                                * (N_sma - 2)
-                                / N_sma
-                                * N_sma_max
-                                / (N_sma_max - 2)
+                                * (n_sma - 4)
+                                / (n_sma_max - 4)
+                                * (n_sma - 2)
+                                / n_sma
+                                * n_sma_max
+                                / (n_sma_max - 2)
                             )
                             / (1 - beta1 ** state["step"])
                         )
@@ -112,12 +110,10 @@ class RAdam(Optimizer):
                     buffered[2] = step_size
 
                 if group["weight_decay"] != 0:
-                    p_data_fp32.add_(
-                        -group["weight_decay"] * group["lr"], p_data_fp32
-                    )
+                    p_data_fp32.add_(-group["weight_decay"] * group["lr"], p_data_fp32)
 
                 # more conservative since it's an approximated value
-                if N_sma >= 5:
+                if n_sma >= 5:
                     denom = exp_avg_sq.sqrt().add_(group["eps"])
                     p_data_fp32.addcdiv_(-step_size, exp_avg, denom)
                 else:
@@ -126,3 +122,6 @@ class RAdam(Optimizer):
                 p.data.copy_(p_data_fp32)
 
         return loss
+
+
+__all__ = ["RAdam"]
