@@ -8,9 +8,9 @@ from torch.optim.optimizer import Optimizer
 class Ralamb(Optimizer):
     """RAdam optimizer with LARS/LAMB tricks.
 
-    Main origins of inspiration:
-        https://github.com/mgrankin/over9000/blob/master/ralamb.py
-        (Apache-2.0 License)
+    Adapted from:
+    https://github.com/mgrankin/over9000/blob/master/ralamb.py
+    (Apache-2.0 License)
     """
 
     def __init__(
@@ -23,7 +23,7 @@ class Ralamb(Optimizer):
     ):
         """
         Args:
-            params (iterable): iterable of parameters to optimize
+            params: iterable of parameters to optimize
                 or dicts defining parameter groups
             lr (float, optional): learning rate (default: 1e-3)
             betas (Tuple[float, float], optional): coefficients used for
@@ -53,6 +53,12 @@ class Ralamb(Optimizer):
         Args:
             closure (callable, optional): A closure that reevaluates
                 the model and returns the loss.
+
+        Returns:
+            computed loss
+
+        Raises:
+            RuntimeError: Ralamb does not support sparse gradients
         """
         loss = None
         if closure is not None:
@@ -65,9 +71,7 @@ class Ralamb(Optimizer):
                     continue
                 grad = p.grad.data.float()
                 if grad.is_sparse:
-                    raise RuntimeError(
-                        "Ralamb does not support sparse gradients"
-                    )
+                    raise RuntimeError("Ralamb does not support sparse gradients")
 
                 p_data_fp32 = p.data.float()
 
@@ -79,9 +83,7 @@ class Ralamb(Optimizer):
                     state["exp_avg_sq"] = torch.zeros_like(p_data_fp32)
                 else:
                     state["exp_avg"] = state["exp_avg"].type_as(p_data_fp32)
-                    state["exp_avg_sq"] = state["exp_avg_sq"].type_as(
-                        p_data_fp32
-                    )
+                    state["exp_avg_sq"] = state["exp_avg_sq"].type_as(p_data_fp32)
 
                 exp_avg, exp_avg_sq = state["exp_avg"], state["exp_avg_sq"]
                 beta1, beta2 = group["betas"]
@@ -96,43 +98,37 @@ class Ralamb(Optimizer):
                 buffered = self.buffer[int(state["step"] % 10)]
 
                 if state["step"] == buffered[0]:
-                    N_sma, radam_step_size = buffered[1], buffered[2]
+                    n_sma, radam_step_size = buffered[1], buffered[2]
                 else:
                     buffered[0] = state["step"]
                     beta2_t = beta2 ** state["step"]
-                    N_sma_max = 2 / (1 - beta2) - 1
-                    N_sma = N_sma_max - 2 * state["step"] * beta2_t / (
-                        1 - beta2_t
-                    )
-                    buffered[1] = N_sma
+                    n_sma_max = 2 / (1 - beta2) - 1
+                    n_sma = n_sma_max - 2 * state["step"] * beta2_t / (1 - beta2_t)
+                    buffered[1] = n_sma
 
                     # more conservative since it"s an approximated value
-                    if N_sma >= 5:
+                    if n_sma >= 5:
                         radam_step_size = math.sqrt(
                             (1 - beta2_t)
-                            * (N_sma - 4)
-                            / (N_sma_max - 4)
-                            * (N_sma - 2)
-                            / N_sma
-                            * N_sma_max
-                            / (N_sma_max - 2)
+                            * (n_sma - 4)
+                            / (n_sma_max - 4)
+                            * (n_sma - 2)
+                            / n_sma
+                            * n_sma_max
+                            / (n_sma_max - 2)
                         ) / (1 - beta1 ** state["step"])
                     else:
                         radam_step_size = 1.0 / (1 - beta1 ** state["step"])
                     buffered[2] = radam_step_size
 
                 if group["weight_decay"] != 0:
-                    p_data_fp32.add_(
-                        -group["weight_decay"] * group["lr"], p_data_fp32
-                    )
+                    p_data_fp32.add_(-group["weight_decay"] * group["lr"], p_data_fp32)
 
                 # more conservative since it"s an approximated value
                 radam_step = p_data_fp32.clone()
-                if N_sma >= 5:
+                if n_sma >= 5:
                     denom = exp_avg_sq.sqrt().add_(group["eps"])
-                    radam_step.addcdiv_(
-                        -radam_step_size * group["lr"], exp_avg, denom
-                    )
+                    radam_step.addcdiv_(-radam_step_size * group["lr"], exp_avg, denom)
                 else:
                     radam_step.add_(-radam_step_size * group["lr"], exp_avg)
 
@@ -147,17 +143,16 @@ class Ralamb(Optimizer):
                 state["adam_norm"] = radam_norm
                 state["trust_ratio"] = trust_ratio
 
-                if N_sma >= 5:
+                if n_sma >= 5:
                     p_data_fp32.addcdiv_(
-                        -radam_step_size * group["lr"] * trust_ratio,
-                        exp_avg,
-                        denom,
+                        -radam_step_size * group["lr"] * trust_ratio, exp_avg, denom,
                     )
                 else:
-                    p_data_fp32.add_(
-                        -radam_step_size * group["lr"] * trust_ratio, exp_avg
-                    )
+                    p_data_fp32.add_(-radam_step_size * group["lr"] * trust_ratio, exp_avg)
 
                 p.data.copy_(p_data_fp32)
 
         return loss
+
+
+__all__ = ["Ralamb"]
