@@ -1,14 +1,13 @@
 import pytest
 
-from .. import __main__ as main
+from catalyst.dl import __main__ as main
 
 
 def test_arg_parser_run():
+    """Docs? Contribution is welcome."""
     parser = main.build_parser()
 
-    args, uargs = parser.parse_known_args(
-        ["run", "--config", "test.yml", "--unknown"]
-    )
+    args, uargs = parser.parse_known_args(["run", "--config", "test.yml", "--unknown"])
 
     assert args.command == "run"
     assert args.configs == ["test.yml"]
@@ -16,16 +15,16 @@ def test_arg_parser_run():
 
 
 def test_run_multiple_configs():
+    """Docs? Contribution is welcome."""
     parser = main.build_parser()
 
-    args, uargs = parser.parse_known_args(
-        ["run", "--config", "test.yml", "test1.yml"]
-    )
+    args, uargs = parser.parse_known_args(["run", "--config", "test.yml", "test1.yml"])
 
     assert args.configs == ["test.yml", "test1.yml"]
 
 
 def test_arg_parser_fail_on_none():
+    """Docs? Contribution is welcome."""
     parser = main.build_parser()
 
     with pytest.raises(SystemExit):
